==> seedsui-react-4.9.4.tgz: package/es/Jcrop/Jcrop.js <==
var _excluded = ["src", "rect", "scale", "options", "onChange", "style"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import Instance from 'jcrop';
import 'jcrop/dist/jcrop.css'; // Jcrop

var Jcrop = forwardRef(function (_ref, ref) {
  var src = _ref.src,
      rect = _ref.rect,
      _ref$scale = _ref.scale,
      scale = _ref$scale === void 0 ? [0.7, 0.5] : _ref$scale,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? {
    multi: false
  } : _ref$options,
      onChange = _ref.onChange,
      style = _ref.style,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  useEffect(function () {
    update();
  }, []); // eslint-disable-line

  function formatPos(argPos) {
    var pos = argPos;

    for (var n in argPos) {
      if (n === 'h') pos['height'] = argPos[n];else if (n === 'w') pos['width'] = argPos[n];
    }

    return pos;
  }

  function update() {
    if (!src || rootRef.current) return;
    Instance.load(rootRef.current).then(function (img) {
      var jcp = Instance.attach(img, options);
      var frame = null;
      var pos = {}; // 按尺寸创建

      if (rect) {
        pos = {
          x: rect[0],
          y: rect[1],
          w: rect[2],
          h: rect[3]
        };
        frame = Instance.Rect.create(pos.x, pos.y, pos.w, pos.h);
        jcp.newWidget(frame); // 按比例创建
      } else {
        var _frame;

        frame = Instance.Rect.sizeOf(jcp.el);
        pos = (_frame = frame).scale.apply(_frame, scale).center(frame.w, frame.h);
        jcp.newWidget(pos);
      }

      if (onChange) onChange({
        pos: formatPos(pos),
        src: src
      });
      jcp.listen('crop.change', function (widget, e) {
        pos = formatPos(widget.pos);
        if (onChange) onChange({
          pos: pos,
          src: src
        });
      });
    })["catch"](function (err) {
      console.error(err);
    });
  }

  return /*#__PURE__*/React.createElement("img", _extends({
    alt: "",
    ref: rootRef
  }, others, {
    style: Object.assign({
      maxWidth: '100%'
    }, style),
    src: src
  }));
});
export default Jcrop;

==> seedsui-react-5.5.8.tgz: package/es/Jcrop/Jcrop.js <==
var _excluded = ["src", "rect", "scale", "options", "onChange", "style"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import Instance from 'jcrop';
import 'jcrop/dist/jcrop.css'; // Jcrop

var Jcrop = forwardRef(function (_ref, ref) {
  var src = _ref.src,
      rect = _ref.rect,
      _ref$scale = _ref.scale,
      scale = _ref$scale === void 0 ? [0.7, 0.5] : _ref$scale,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? {
    multi: false
  } : _ref$options,
      onChange = _ref.onChange,
      style = _ref.style,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  useEffect(function () {
    update();
  }, []); // eslint-disable-line

  function formatPos(argPos) {
    var pos = argPos;

    for (var n in argPos) {
      if (n === 'h') pos['height'] = argPos[n];else if (n === 'w') pos['width'] = argPos[n];
    }

    return pos;
  }

  function update() {
    if (!src || rootRef.current) return;
    Instance.load(rootRef.current).then(function (img) {
      var jcp = Instance.attach(img, options);
      var frame = null;
      var pos = {}; // 按尺寸创建

      if (rect) {
        pos = {
          x: rect[0],
          y: rect[1],
          w: rect[2],
          h: rect[3]
        };
        frame = Instance.Rect.create(pos.x, pos.y, pos.w, pos.h);
        jcp.newWidget(frame); // 按比例创建
      } else {
        var _frame;

        frame = Instance.Rect.sizeOf(jcp.el);
        pos = (_frame = frame).scale.apply(_frame, scale).center(frame.w, frame.h);
        jcp.newWidget(pos);
      }

      if (onChange) onChange({
        pos: formatPos(pos),
        src: src
      });
      jcp.listen('crop.change', function (widget, e) {
        pos = formatPos(widget.pos);
        if (onChange) onChange({
          pos: pos,
          src: src
        });
      });
    }).catch(function (err) {
      console.error(err);
    });
  }

  return /*#__PURE__*/React.createElement("img", _extends({
    alt: "",
    ref: rootRef
  }, others, {
    style: Object.assign({
      maxWidth: '100%'
    }, style),
    src: src
  }));
});
export default Jcrop;
